pub type AllPalletsWithSystem = (System, PalletWithExternalOrigin);Expand description
All pallets included in the runtime as a nested tuple of types.
pub type AllPalletsWithSystem = (System, PalletWithExternalOrigin);All pallets included in the runtime as a nested tuple of types.